@@ -6,7 +6,7 @@
 ;; Maintainer: notmuch-indicator Development <~protesilaos/notmuch-indicator@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/notmuch-indicator
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/notmuch-indicator
-;; Version: 0.1.1
+;; Version: 0.2.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mail
 
@@ -68,6 +68,8 @@
 ;;             (:terms "--output threads tag:loveletter" :label "💕")))
 ;;
 ;; These form a string which realistically is like: @50 😱1000 💕0.
+;; Each component is clickable: it runs `notmuch-search' on the
+;; applicable `:terms'.
 ;;
 ;; The user option `notmuch-indicator-refresh-count' determines how
 ;; often the indicator will be refreshed.  It accepts a numeric argument
@@ -80,7 +82,7 @@
 ;; The user option `notmuch-indicator-hide-empty-counters' hides zero
 ;; counters from the indicator, when it is set to a non-nil value.
 ;;
-;; Finally, and albeit obvious, the backronym for this package is
+;; Finally, and albeit obvious, the backronym for this package is:
 ;; notmuch-... Increasingly in Need of Displaying Inconsequential
 ;; Counters Alongside Trivia that Obscure Reality.
 
@@ -166,11 +168,23 @@ option `notmuch-indicator-refresh-count'."
    (shell-command-to-string
     (format "notmuch count %s" terms))))
 
-(defun notmuch-indicator--format-label (label count face)
-  "Format LABEL, COUNT, FACE of `notmuch-indicator-args'."
-  (if (and face label)
-      (format "%s%s " (propertize label 'face face) count)
-    (format "%s%s " (or label "") count)))
+(declare-function
+ notmuch-search "notmuch"
+ (&optional query oldest-first target-thread target-line no-display))
+
+(defun notmuch-indicator--format-label (label count face terms)
+  "Format LABEL, COUNT, FACE and TERMS of `notmuch-indicator-args'."
+  (let ((map (make-sparse-keymap)))
+    (define-key map [mode-line mouse-1]
+                (lambda () (interactive) (notmuch-search terms)))
+    (propertize
+     (format "%s%s "
+             (if (and face label)
+                 (propertize label 'face face)
+               (or label ""))
+             count)
+     'help-echo (format "mouse-1: Open notmuch search for `%s'" terms)
+     'local-map map)))
 
 (defun notmuch-indicator--format-output (properties)
   "Format PROPERTIES of `notmuch-indicator-args'."
@@ -181,14 +195,14 @@ option `notmuch-indicator-refresh-count'."
       (notmuch-indicator--format-label
        (plist-get properties :label)
        count
-       (plist-get properties :face)))))
+       (plist-get properties :face)
+       (plist-get properties :terms)))))
 
 (defun notmuch-indicator--return-count ()
   "Parse `notmuch-indicator-args' and format them as single string."
   (mapconcat
-   (lambda (props)
-     (notmuch-indicator--format-output props))
-   notmuch-indicator-args))
+   #'notmuch-indicator--format-output
+   notmuch-indicator-args ""))
 
 (defvar notmuch-indicator-string ""
   "String showing the `notmuch-indicator' state.
